# TL;DR

This reference documentation is for developers who want to learn more about the internals of the Workflow Orchestrator. For more conceptual and high-level documentation, head over to the [Architecture](../architecture/tldr.md) section of the documentation. This is a mix of user-guide style docs and documentation of the actual python classes and functions in use in the `orchestrator-core`. Many of these function and class docs are also available in the code base directly from your IDE.
